@@ -397,6 +397,8 @@ class PolygonAnnotation(Annotation):
         base_dict = super().to_dict()
         base_dict.update({
             'points': [(point.x(), point.y()) for point in self.points],
+            'area': self.calculate_area(),
+            'perimeter': self.calculate_perimeter()
         })
         return base_dict
 
@@ -441,4 +443,4 @@ class PolygonAnnotation(Annotation):
                 f"image_path={self.image_path}, "
                 f"label={self.label.short_label_code}, "
                 f"data={self.data}, "
-                f"machine_confidence={self.machine_confidence})")
\ No newline at end of file
+                f"machine_confidence={self.machine_confidence})")
