@@ -7,7 +7,6 @@ import os
 
 import numpy as np
 
-from superqt import QRangeSlider
 from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import (QApplication, QMessageBox, QLabel, QGroupBox, QFormLayout,
                              QComboBox, QSlider)
@@ -30,7 +29,7 @@ from coralnet_toolbox.utilities import check_model_architecture
 class Detect(Base):
     def __init__(self, main_window, parent=None):
         super().__init__(main_window, parent)
-        self.setWindowTitle("Deploy Detection Model")
+        self.setWindowTitle("Deploy Detection Model (Ctrl + 2)")
 
         self.task = 'detect'
 
@@ -81,14 +80,21 @@ class Detect(Base):
         min_val, max_val = self.main_window.get_area_thresh()
         self.area_thresh_min = int(min_val * 100)
         self.area_thresh_max = int(max_val * 100)
-        self.area_threshold_slider = QRangeSlider(Qt.Horizontal)
-        self.area_threshold_slider.setRange(0, 100)
-        self.area_threshold_slider.setValue((self.area_thresh_min, self.area_thresh_max))
-        self.area_threshold_slider.setTickPosition(QSlider.TicksBelow)
-        self.area_threshold_slider.setTickInterval(10)
-        self.area_threshold_slider.valueChanged.connect(self.update_area_label)
+        self.area_threshold_min_slider = QSlider(Qt.Horizontal)
+        self.area_threshold_min_slider.setRange(0, 100)
+        self.area_threshold_min_slider.setValue(self.area_thresh_min)
+        self.area_threshold_min_slider.setTickPosition(QSlider.TicksBelow)
+        self.area_threshold_min_slider.setTickInterval(10)
+        self.area_threshold_min_slider.valueChanged.connect(self.update_area_label)
+        self.area_threshold_max_slider = QSlider(Qt.Horizontal)
+        self.area_threshold_max_slider.setRange(0, 100)
+        self.area_threshold_max_slider.setValue(self.area_thresh_max)
+        self.area_threshold_max_slider.setTickPosition(QSlider.TicksBelow)
+        self.area_threshold_max_slider.setTickInterval(10)
+        self.area_threshold_max_slider.valueChanged.connect(self.update_area_label)
         self.area_threshold_label = QLabel(f"{self.area_thresh_min:.2f} - {self.area_thresh_max:.2f}")
-        layout.addRow("Area Threshold", self.area_threshold_slider)
+        layout.addRow("Area Threshold Min", self.area_threshold_min_slider)
+        layout.addRow("Area Threshold Max", self.area_threshold_max_slider)
         layout.addRow("", self.area_threshold_label)
 
         # SAM dropdown
@@ -210,6 +216,7 @@ class Detect(Base):
             conf=self.main_window.get_uncertainty_thresh(),
             iou=self.main_window.get_iou_thresh(),
             device=self.main_window.device,
+            half=True,
             stream=True
         )
 
